% Author: Bodo Rosenhahn, Leibinz University of Hannover
% some called routines have been implemented by others (see header)

% The programme contains two parts:
%(a) detect cells in images using a simple Hough transform
%(b) segment the first 5 detected cells using region growing 

% Parts of this programme has been used to generate the data for
% the article
%  
% Video analysis of osmotic cell response during cryopreservation
% Ralf Spindler, Bodo Rosenhahn,  Nicola Hofmann, Birgit Glasmacher
% Cryobiology


%%
clear;

% find 100 Cells
numCells=100;
% The image is already smoothed, using the anisotropic diffusion function
% provided with the data
filename='Example.jpg'
I = im2double(imread(filename));
IS=I(:,:,1);
ISO=IS;
%Speed up computation, this is just an example !
IS = imresize(IS, 0.3);
imshow(IS);
pt1=zeros(2,3);
pts1=[];ptsS1=[];
[xS1 yS1 r HA]=HoughCircleDet(IS,100);
%Hough Array (radius 19)
figure(1)
mesh(HA(:,:,10))
figure(2)
%Visualization
imshow(IS);
pts1(:,2)=xS1;
pts1(:,1)=yS1;
ptsS1(:,2)=xS1*1/0.3;
ptsS1(:,1)=yS1*1/0.3;
for i=1:numCells
    hold on
    num_str=sprintf('%d',i);
    plot(pts1(i,1),pts1(i,2),'o');
    text(pts1(i,1)+6,pts1(i,2),num_str,'Color','black','FontSize',12);
    drawnow;
    hold off
end

%%
% segment the first 5 Cells ...
% Tracking of sequences is then straight forward ...
% don't forger to relocate the cells +
% parameters can be updated automatically ... !
% (not provided)

figure(3)
for i=1:5
    i
    [Dist,im,im2]=SegmentCell(i,ptsS1(i,:),ISO);
    subplot(1,5,i)
    imshow(im+im2)
end

